<?php
session_start();
require '../conn.php'; // Ensure correct path for the connection file

// Ensure user session is set
if (!isset($_SESSION['pro'])) {
    die("Access Denied. Province session not set.");
}

$province = $_SESSION['pro']; // Get province from session
$position = $province . " Coordinator"; // Auto-set position

// Handle Form Submission
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $name = trim($_POST['name']);
    $feedback = trim($_POST['feedback']);
    $rating = (int)$_POST['rating'];

    if (!empty($name) && !empty($feedback) && ($rating >= 1 && $rating <= 5)) {
        $stmt = $conn->prepare("INSERT INTO coordinators_feedback (name, position, province, feedback, rating) VALUES (:name, :position, :province, :feedback, :rating)");
        $stmt->bindParam(':name', $name);
        $stmt->bindParam(':position', $position);
        $stmt->bindParam(':province', $province);
        $stmt->bindParam(':feedback', $feedback);
        $stmt->bindParam(':rating', $rating);

        if ($stmt->execute()) {
            echo "<script>alert('Feedback submitted successfully!'); window.location.reload();</script>";
        } else {
            echo "<script>alert('Error submitting feedback!');</script>";
        }
    } else {
        echo "<script>alert('Please fill in all fields correctly!');</script>";
    }
}

// Fetch Feedback for this Province
$stmt = $conn->prepare("SELECT * FROM coordinators_feedback WHERE province = :province ORDER BY created_at DESC");
$stmt->bindParam(':province', $province);
$stmt->execute();
$feedbacks = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Coordinator Feedback</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body class="bg-light">
    <div class="container my-5">
        <h2 class="text-center">Coordinator Feedback (<?= htmlspecialchars($province) ?>)</h2>

        <!-- Feedback Form -->
        <div class="card mb-4">
            <div class="card-body">
                <form method="POST" action="">
                    <div class="mb-3">
                        <label class="form-label">Name</label>
                        <input type="text" name="name" class="form-control" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Province</label>
                        <input type="text" name="province" class="form-control" value="<?= htmlspecialchars($province) ?>" readonly>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Position</label>
                        <input type="text" name="position" class="form-control" value="<?= htmlspecialchars($position) ?>" readonly>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Feedback</label>
                        <textarea name="feedback" class="form-control" rows="3" required></textarea>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Rating</label>
                        <select name="rating" class="form-select" required>
                            <option value="5">★★★★★ (5 Stars)</option>
                            <option value="4">★★★★☆ (4 Stars)</option>
                            <option value="3">★★★☆☆ (3 Stars)</option>
                            <option value="2">★★☆☆☆ (2 Stars)</option>
                            <option value="1">★☆☆☆☆ (1 Star)</option>
                        </select>
                    </div>
                    <button type="submit" class="btn btn-primary">Submit Feedback</button>
                </form>
            </div>
        </div>

        <!-- Display Feedback -->
        <div class="row">
            <?php foreach ($feedbacks as $fb) : ?>
                <div class="col-md-6">
                    <div class="card mb-3">
                        <div class="card-body">
                            <p class="fw-bold"><?= htmlspecialchars($fb['name']) ?> - <small class="text-muted"><?= htmlspecialchars($fb['position']) ?></small></p>
                            <p>“<?= htmlspecialchars($fb['feedback']) ?>”</p>
                            <div class="text-warning">
                                <?php for ($i = 0; $i < 5; $i++) : ?>
                                    <i class="ti ti-star<?= $i < $fb['rating'] ? '-filled' : '' ?>"></i>
                                <?php endfor; ?>
                            </div>
                            <p class="small text-muted"><?= date("F j, Y, g:i a", strtotime($fb['created_at'])) ?></p>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
